@@ -34,6 +34,7 @@ RE_DDDB_TAG = r"^.{1,50}$"
 RE_CONDDB_TAG = r"^.{1,50}$"
 
 RE_COMMENT = r"(.{1,5000})"
+DQ_FLAGS_SCHEMA = Seq(Enum(["BAD", "OK", "EXPRESS_OK", "UNCHECKED"]))
 
 BASE_JOB_SCHEMA = {
     "application": Regex(RE_APPLICATION),
@@ -60,13 +61,16 @@ BASE_JOB_SCHEMA = {
     "completion_percentage": Float(),
 }
 INPUT_SCHEMAS = {
-    "bk_query": Map({"bk_query": Str(), Opt("n_test_lfns"): Int()}),
+    "bk_query": Map(
+        {"bk_query": Str(), Opt("n_test_lfns"): Int(), Opt("dq_flags"): DQ_FLAGS_SCHEMA}
+    ),
     "job_name": Map({"job_name": Str()}),
     "transform_ids": Map(
         {
             "transform_ids": Seq(Int()),
             "filetype": Regex(RE_OUTPUT_FILE_TYPE),
             Opt("n_test_lfns"): Int(),
+            Opt("dq_flags"): DQ_FLAGS_SCHEMA,
         }
     ),
 }
